package gov.usgs.earthquake.nshmp.netcdf.reader;

import java.io.IOException;

import gov.usgs.earthquake.nshmp.netcdf.data.NetcdfData;
import gov.usgs.earthquake.nshmp.netcdf.data.NetcdfDataGroundMotions;
import gov.usgs.earthquake.nshmp.netcdf.data.NetcdfShape;
import gov.usgs.earthquake.nshmp.netcdf.data.NetcdfShape.IndexKey;
import gov.usgs.earthquake.nshmp.netcdf.reader.NetcdfUtils.Key;

import ucar.nc2.Group;

/**
 * Read in ground motions NetCDF files
 *
 * @author U.S. Geological Survey
 */
public class ReaderGroundMotions extends Reader {

  public ReaderGroundMotions(Group targetGroup) throws IOException {
    super(targetGroup);
  }

  @Override
  NetcdfShape buildNetcdfShape(Group group) {
    var vData = group.findVariableLocal(Key.GROUND_MOTION);
    return NetcdfShape.builder()
        .add(IndexKey.IMT, vData.findDimensionIndex(Key.IMT))
        .add(IndexKey.LATITUDE, vData.findDimensionIndex(Key.LAT))
        .add(IndexKey.LONGITUDE, vData.findDimensionIndex(Key.LON))
        .add(IndexKey.SITE_CLASS, vData.findDimensionIndex(Key.SITE_CLASS))
        .build();
  }

  @Override
  NetcdfDataGroundMotions readData(Group targetGroup) throws IOException {
    NetcdfData netcdfData = super.readData(targetGroup);
    return new NetcdfDataGroundMotions(netcdfData);
  }
}
