package gov.usgs.earthquake.nshmp.netcdf;

import static com.google.common.base.Preconditions.checkArgument;

import java.io.IOException;
import java.nio.file.Path;

import gov.usgs.earthquake.nshmp.geo.Location;
import gov.usgs.earthquake.nshmp.gmm.NehrpSiteClass;
import gov.usgs.earthquake.nshmp.netcdf.data.BoundingData;
import gov.usgs.earthquake.nshmp.netcdf.data.NetcdfDataHazardCurves;
import gov.usgs.earthquake.nshmp.netcdf.data.StaticData;
import gov.usgs.earthquake.nshmp.netcdf.data.StaticDataHazardCurves;
import gov.usgs.earthquake.nshmp.netcdf.reader.BoundingReaderHazardCurves;
import gov.usgs.earthquake.nshmp.netcdf.reader.ReaderHazardCurves;

import ucar.nc2.dataset.NetcdfDatasets;

/**
 * NetCDF data for hazard curves.
 *
 * @author U.S. Geological Survey
 */
public class NetcdfHazardCurves extends Netcdf<StaticDataHazardCurves> {

  public NetcdfHazardCurves(Path netcdfPath) {
    super(netcdfPath);
  }

  @Override
  public BoundingData<StaticDataHazardCurves> boundingData(Location site) {
    return new BoundingReaderHazardCurves(this, site).boundingData();
  }

  @Override
  public NetcdfDataHazardCurves netcdfData() {
    return (NetcdfDataHazardCurves) netcdfData;
  }

  @Override
  public StaticData<StaticDataHazardCurves> staticData(Location site) {
    return boundingData(site).get(site);
  }

  @Override
  public StaticDataHazardCurves staticData(Location site, NehrpSiteClass siteClass) {
    checkArgument(
        netcdfData.siteClasses().contains(siteClass),
        "Site class [" + siteClass + "] not supported");
    return staticData(site).get(siteClass);
  }

  @Override
  ReaderHazardCurves getNetcdfData(Path netcdfPath) {
    try (var ncd = NetcdfDatasets.openDataset(netcdfPath.toString())) {
      var group = ncd.getRootGroup();
      return new ReaderHazardCurves(group);
    } catch (IOException e) {
      throw new RuntimeException("Could not read Netcdf file [" + netcdfPath + "]");
    }
  }
}
